@@ -1,5 +1,6 @@
 class TypedPyDefaults:
     additional_properties_default = True
     compact_serialization_default = False
-    automatic_enum_conversion = False
+    automatic_enum_conversion = True
     support_json_schema_v6 = False
+    uniqueness_features_enabled = False
